@@ -1,12 +1,18 @@
 '''
 # MCA Projen JSii Example
 
+[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
+[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/marciocadev/mca-projen-jsii-example)
 [![npm version](https://badge.fury.io/js/mca-projen-jsii-example.svg)](https://badge.fury.io/js/mca-projen-jsii-example)
 [![PyPI version](https://badge.fury.io/py/mca-projen-jsii-example.svg)](https://badge.fury.io/py/mca-projen-jsii-example)
 [![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example)
 [![Go Reference](https://pkg.go.dev/badge/github.com/marciocadev/mca-projen-jsii-example-go.svg)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go)
 [![release](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml/badge.svg)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml)
 
+[![Maven Central](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example.svg?label=maven%20central)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
+
+[![Go Reference](https://pkg.go.dev/badge/github.com/projen/projen-go.svg)](https://pkg.go.dev/github.com/projen/projen-go/projen)
+
 The **MCA Projen JSii Example** it's a test project to learn how deploy at NPM, PyPi and Maven repositories, auto-versioning and runing git actions on commits
 '''
 import abc
